@@ -12,7 +12,7 @@ import pyautogui
 # define the function
 # the function takes 2 arguments, the x and y coordinates of the pixel
 # returns a tuple of the RGBA values of the pixel
-def get_pixel_color(x, y):
+def pixel(x, y):
     if (platform == "darwin"):
         os.system('screencapture -R ' + str(x) + ',' + str(y) + ',1,1 -c')
         im = Pasteboard().get_contents(TIFF)
